django\_sorcery.management.commands.sorcery module
==================================================

.. automodule:: django_sorcery.management.commands.sorcery
   :members:
   :undoc-members:
   :show-inheritance:
